<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor del sistema</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>El Monitor del sistema és una eina per monitorar la càrrega del sistema en temps real, veure i controlar els processos i serveis que s&apos;executen al sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Amaga&apos;n els detalls</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Ús general</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Ús individual</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Escriptura</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segons</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 dies, %2 hores, %3 minuts</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Ús</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Freqüència actual</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Freqüència</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proveïdor</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Sòcols</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Processadors lògics</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualització</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Cau L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Cau L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Cau L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Cau L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Càrrega mitjana</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Descriptors de fitxers</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processos</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Fils</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nom d&apos;amfitrió</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Tipus de SO</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Temps d&apos;activitat</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segons</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Cap resultat de la cerca</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>actiu</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>es recarrega</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inactiu</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fallat</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>s&apos;activa</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>es desactiva</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>estub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>no trobat</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>mala configuració</translation>
    </message>
    <message>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>fusionat</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>emmascarat</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>carregat</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>habilitat</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>inhabilitat</translation>
    </message>
    <message>
        <source>static</source>
        <translation>estàtic</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transitori</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirecte</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>entorn habilitat</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>emmascarat</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>generat</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>mort</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>inici pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>inici</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>inici post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>funcionant</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>ha sortit</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>es recarrega</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>atura</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>aturada-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>aturada-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>aturada-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>aturada post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fallat</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>autoreinici</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Usat</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Compartit</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>A la cau</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Memòries intermèdies</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Intercanvi a la cau</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actiu</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactiu</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Brut</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapat</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Intercanvi total</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Intercanvi lliure</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Placa</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Velocitat de lectura</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Velocitat d&apos;escriptura</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capacitat</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Sectors de lectura</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Lectures</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sectors de lectura</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Lectures fusionades</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sectors escrits</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Escriptures completades</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Escriptures fusionades</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Escriptures</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sectors escrits</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Escriptures fusionades</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Acabar aquest procés pot causar pèrdua de dades.
Segur que voleu continuar?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Acaba el procés</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forçar l&apos;acabament d&apos;aquest procés pot causar pèrdua de dades.
Segur que voleu continuar?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forçar l&apos;acabament d&apos;aquesta aplicació pot causar pèrdua de dades.
Segur que voleu continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Força&apos;n l&apos;acabament</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Acaba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Adreça IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Màscara de xarxa:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Difusió:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Llargada de prefix:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Abast:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Tipus de connexió</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>Tipus de connexió:</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Qualitat de l&apos;enllaç</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Potència del senyal</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Nivell de soroll</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Amplada de banda</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paquets RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bytes RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Errors RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX caigut/s</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Excessos RX</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Marc RX</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paquets RX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bytes RX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Errors RX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Excessos TX</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Transportista TX</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX caigut/s</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Línia d&apos;ordres</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Hora d&apos;inici</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Cliqueu a l&apos;aplicació que vulgueu acabar.</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Rep</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disc</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escriptura de disc</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercanvi</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>No habilitat</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Recepció total</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Enviament total</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discs</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Molt alta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Molt baixa</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalitzada</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>No vàlid</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Ha fallat canviar la prioritat del procés.</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplicacions</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Els processos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tots els processos</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Es carrega</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Ha fallat interrompre el procés.</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Ha fallat reprendre el procés.</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Ha fallat matar el procés.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Ha fallat enviar el senyal al procés.</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Ha fallat acabar el procés.</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(S&apos;executen %2 aplicacions i %3 processos.)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Sense resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Safata</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Mostra la ubicació del procés</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propietats</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Acaba el procés</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reprèn el procés</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Mata el procés</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Canvia&apos;n la prioritat</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspèn el procés</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Prioritat personalitzada</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Canvia</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memòria</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escriptura de disc</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disc</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Bé</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritat</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Memòria compartida</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Memòria virtual</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Sense suport</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Protecció del sistema</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Mostra avisos quan l&apos;ús superi els llindars.</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificacions</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Llindar d&apos;advertència de la CPU (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Llindar d&apos;advertència de la memòria (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Interval d&apos;advertència (min)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Ha fallat establir el tipus d&apos;inici del servei.</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: no s&apos;ha pogut establir el tipus d&apos;inici del servei a causa de la fallada del subprocés.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nom de la instància de sistema</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Refresca-ho</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Tipus d&apos;inici</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actiu</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Tipus d&apos;inici</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Modificable)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Interval: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Força l&apos;acabament de l&apos;aplicació</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandeix</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compacta</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processos</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Serveis</translation>
    </message>
</context>
</TS>
